from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware

from app.api.tasks import router as tasks_router
from app.db.session import engine
from app.db.base import Base

app = FastAPI(
    title="Task Manager API",
    description="A simple Task Manager API built with FastAPI",
    version="1.0.0",
    openapi_url="/openapi.json",
)

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

Base.metadata.create_all(bind=engine)

app.include_router(tasks_router, prefix="/api/tasks", tags=["tasks"])


@app.get("/")
def root():
    return {"title": "Task Manager API", "documentation": "/docs", "health": "/health"}


@app.get("/health")
def health_check():
    return {"status": "healthy", "service": "Task Manager API"}
